@@ -1,3 +1,6 @@
+#include "strings.cpp"
+#include "io.cpp"
+#include "log.cpp"
 #include "kmplayertypes.cpp"
 #include "triestring.cpp"
 #include "expression.cpp"
