@@ -165,21 +165,6 @@ void app_set_playing (Application *app, int p) {
     }
 }
 
-static void _app_setup_window (GtkWidget * w, Application *app) {
-    gtk_widget_add_events (w,
-            GDK_EXPOSURE_MASK | GDK_VISIBILITY_NOTIFY_MASK |
-            GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK |
-            GDK_STRUCTURE_MASK);
-    g_signal_connect (G_OBJECT (w), "realize",
-        GTK_SIGNAL_FUNC (cb_view_area_realized), app);
-    g_signal_connect (G_OBJECT (w), "expose-event",
-        GTK_SIGNAL_FUNC (cb_view_area_expose), app);
-    g_signal_connect (G_OBJECT (w), "button-press-event",
-        GTK_SIGNAL_FUNC (cb_view_area_button_press), app);
-    g_signal_connect (G_OBJECT (w), "key-press-event",
-        GTK_SIGNAL_FUNC (cb_view_area_key_press), app);
-}
-
 void app_full_screen (Application *app) {
     if (!app->fullscreen) {
         app->fullscreen = true;
@@ -187,7 +172,9 @@ void app_full_screen (Application *app) {
         gtk_widget_hide (app->playlist_area);
         gtk_widget_hide (app->toolbar_area);
         gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 410);
+        gtk_widget_show (GTK_WIDGET (app->tb_favorites));
         gtk_window_fullscreen (app->window);
+        gtk_widget_grab_focus (app->view_area);
         app_update_screen_blanking (app);
     }
 }
@@ -195,16 +182,19 @@ void app_full_screen (Application *app) {
 void app_normal_screen (Application *app) {
     if (app->fullscreen) {
         app->fullscreen = false;
+        app->show_playlist = true;
         gtk_window_unfullscreen (app->window);
         gtk_widget_show (app->playlist_area);
         gtk_widget_hide (app->video_stop);
         gtk_widget_hide (app->title_area);
+        gtk_widget_hide (GTK_WIDGET (app->tb_favorites));
         gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 354);
         gtk_widget_show (app->toolbar_area);
         if (app->controls_timer) {
             g_source_remove (app->controls_timer);
             app->controls_timer = 0;
         }
+        gtk_widget_grab_focus (app->playlist_view);
     }
     app_update_screen_blanking (app);
 }
@@ -238,7 +228,8 @@ void app_show_controls (Application *app)
             g_source_remove (app->controls_timer);
         app->controls_timer = g_timeout_add (2000, (GSourceFunc) _controlsTimeout, app);
         gtk_widget_show_all (app->video_stop);
-        gtk_widget_show (app->toolbar_area);
+        if (app->show_playlist)
+            gtk_widget_show (app->toolbar_area);
     }
 }
 
@@ -254,8 +245,8 @@ static void _appShowTitle (Application *app)
             img = gtk_image_new_from_pixbuf (pix);*/
         if (!app->video_title) {
             app->video_title = gtk_tool_button_new (img, val);
-            gtk_fixed_put(GTK_FIXED (app->title_area),
-                    GTK_WIDGET (app->video_title), 0, 0);
+            gtk_container_add (GTK_CONTAINER (app->title_area),
+                    GTK_WIDGET (app->video_title));
             gtk_widget_show_all (GTK_WIDGET (app->video_title));
         } else {
             gtk_tool_button_set_label (GTK_TOOL_BUTTON (app->video_title), val);
@@ -321,11 +312,7 @@ static void callback_file_new (GtkButton * button, Application * app) {
 
 static gboolean
 locationbarLostFocus (GtkWidget *gw, GdkEventFocus *gef, Application *app) {
-    int n = gtk_toolbar_get_n_items (GTK_TOOLBAR (app->main_toolbar));
-    int i;
     (void)gw; (void)gef;
-    for (i = 5; i < n; i++)
-        gtk_widget_show (GTK_WIDGET (gtk_toolbar_get_nth_item (GTK_TOOLBAR (app->main_toolbar), i)));
     app_set_playing (app, app->playing);
     gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (app->location_bar)->child), 0, 0);
     return false;
@@ -351,6 +338,17 @@ static void windowTopMost (GObject * self, GParamSpec *gps, Application * app) {
         app_update_screen_blanking (app);
 }
 
+static void infoAreaRealized (GtkWidget *widget, gpointer p)
+{
+    GdkColor color;
+    (void)p;
+
+    color.red = 32 * 65535 / 255;
+    color.green = 32 * 65535 / 255;
+    color.blue = 32 * 65535 / 255;
+    gtk_widget_modify_bg (widget, GTK_STATE_NORMAL, &color);
+}
+
 /* Create the menu items needed for the main view */
 static void create_toolbar (Application * app) {
     /* Create needed variables */
@@ -374,6 +372,8 @@ static void create_toolbar (Application * app) {
     app->tb_item_playlist_commit = GTK_WIDGET (gtk_tool_button_new (
                 gtk_image_new_from_icon_name(
                     "general_refresh", HILDON_ICON_SIZE_TOOLBAR), NULL));
+    app->tb_favorites = gtk_tool_button_new (gtk_image_new_from_icon_name (
+                "kmplayer-fav-tb", HILDON_ICON_SIZE_TOOLBAR), NULL);
     /* Create toolbar combobox item */
     app->tb_location = gtk_tool_item_new();
     app->tb_progress = gtk_tool_item_new();
@@ -407,6 +407,7 @@ static void create_toolbar (Application * app) {
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_next, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_stop, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_save, -1);
+    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_favorites, -1);
 
     /* Add signal lister to "Close" button */
     g_signal_connect (G_OBJECT (app->tb_go), "clicked",
@@ -429,6 +430,8 @@ static void create_toolbar (Application * app) {
         G_CALLBACK (cb_playlist_edit_commit), app);
     g_signal_connect (G_OBJECT (app->progress_bar), "value-changed",
         G_CALLBACK (progressValueChanged), app);
+    g_signal_connect (G_OBJECT (app->tb_favorites), "clicked",
+        G_CALLBACK (cb_favorites_add), app);
 
     /* Add toolbar to 'vbox' of HildonAppView */
     gtk_widget_show_all (GTK_WIDGET (app->main_toolbar));
@@ -436,8 +439,9 @@ static void create_toolbar (Application * app) {
     gtk_widget_hide (GTK_WIDGET (app->tb_progress));
     gtk_widget_hide (GTK_WIDGET (app->tb_pause));
     gtk_widget_hide (GTK_WIDGET (app->tb_stop));
+    gtk_widget_hide (GTK_WIDGET (app->tb_favorites));
     gtk_widget_set_size_request (app->main_toolbar, 800, 70);
-    gtk_fixed_put(GTK_FIXED (app->toolbar_area), app->main_toolbar, 0, 0);
+    gtk_container_add (GTK_CONTAINER (app->toolbar_area), app->main_toolbar);
 }
 
 static GtkWidget *makeMenuButton (const char *text) {
@@ -584,6 +588,8 @@ int main (int argc, char* argv[]) {
     PangoFontDescription *pfd;
     Application *app;
     GtkWidget *video_stop;
+    GtkWidget *info_box;
+    GtkWidget *info_align;
 
     g_thread_init (NULL);
     /* Create needed variables */
@@ -629,11 +635,13 @@ int main (int argc, char* argv[]) {
 
     app->window_area = gtk_fixed_new ();
     app->view_area = gtk_fixed_new ();
-    app->video_stop = gtk_fixed_new ();
-    app->title_area = gtk_fixed_new ();
+    app->video_stop = gtk_event_box_new ();
+    app->title_area = gtk_event_box_new ();
     app->playlist_area = hildon_pannable_area_new ();
-    app->toolbar_area = gtk_fixed_new ();
-    app->info_area = gtk_vbox_new (false, 0);
+    app->toolbar_area = gtk_event_box_new ();
+    app->info_area = gtk_event_box_new ();
+    info_box = gtk_vbox_new (false, 0);
+    info_align = gtk_alignment_new (0, 0, 1, 1);
 
     gtk_widget_set_size_request (app->video_stop, 70, 70);
     gtk_widget_set_size_request (app->title_area, 600, 70);
@@ -642,9 +650,6 @@ int main (int argc, char* argv[]) {
     gtk_widget_set_size_request (app->info_area, 400, 140);
 
     gtk_fixed_set_has_window (GTK_FIXED (app->view_area), TRUE);
-    gtk_fixed_set_has_window (GTK_FIXED (app->video_stop), TRUE);
-    gtk_fixed_set_has_window (GTK_FIXED (app->title_area), TRUE);
-    gtk_fixed_set_has_window (GTK_FIXED (app->toolbar_area), TRUE);
 
     g_object_set (G_OBJECT (app->playlist_area),
             "mov-mode", HILDON_MOVEMENT_MODE_BOTH, NULL);
@@ -654,26 +659,39 @@ int main (int argc, char* argv[]) {
     app->video_socket = gtk_socket_new ();
     gtk_widget_set_size_request (app->video_socket, 50, 50);
     gtk_fixed_put (GTK_FIXED (app->view_area), app->video_socket, -60, -60);
-    _app_setup_window (app->view_area, app);
 
     video_stop = GTK_WIDGET (gtk_tool_button_new (gtk_image_new_from_icon_name(
                     "general_close", HILDON_ICON_SIZE_TOOLBAR), NULL));
 
-    gtk_fixed_put (GTK_FIXED (app->video_stop), video_stop, 0, 0);
-
     g_signal_connect (G_OBJECT (video_stop), "clicked",
             G_CALLBACK (cb_playlist_stop), app->control);
-
+    gtk_widget_add_events (app->view_area,
+            GDK_EXPOSURE_MASK | GDK_VISIBILITY_NOTIFY_MASK |
+            GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK |
+            GDK_STRUCTURE_MASK);
+    g_signal_connect (G_OBJECT (app->view_area), "expose-event",
+            GTK_SIGNAL_FUNC (cb_view_area_expose), app);
+    g_signal_connect (G_OBJECT (app->view_area), "button-press-event",
+            GTK_SIGNAL_FUNC (cb_view_area_button_press), app);
+    g_signal_connect (G_OBJECT (app->view_area), "key-press-event",
+            GTK_SIGNAL_FUNC (cb_view_area_key_press), app);
     g_signal_connect (app->program, "notify::is-topmost",
-        GTK_SIGNAL_FUNC (programTopMost), app);
+            GTK_SIGNAL_FUNC (programTopMost), app);
     g_signal_connect (G_OBJECT (main_window), "delete-event",
-        GTK_SIGNAL_FUNC (cb_mainview_delete), app);
+            GTK_SIGNAL_FUNC (cb_mainview_delete), app);
     g_signal_connect (G_OBJECT (main_window), "notify::is-topmost",
-        GTK_SIGNAL_FUNC (windowTopMost), app);
+            GTK_SIGNAL_FUNC (windowTopMost), app);
     g_signal_connect (G_OBJECT (app->video_socket), "plug-added",
             GTK_SIGNAL_FUNC (cbPluginAdded), app);
     g_signal_connect (G_OBJECT (app->video_socket), "plug-removed",
             GTK_SIGNAL_FUNC (cbPluginRemoved), app);
+    g_signal_connect (G_OBJECT (app->view_area), "realize",
+            GTK_SIGNAL_FUNC (cb_view_area_realized), app);
+    g_signal_connect (G_OBJECT (app->info_area), "realize",
+            GTK_SIGNAL_FUNC (infoAreaRealized), NULL);
+    /*g_signal_connect (G_OBJECT (app->video_stop), "realize",
+            GTK_SIGNAL_FUNC (videoStopRealized), NULL);*/
+
     app->infopanel_view = gtk_text_view_new ();
     app->info_viewport = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (app->info_viewport),
@@ -690,22 +708,23 @@ int main (int argc, char* argv[]) {
     app->html_infopanel_view = gtk_html_new ();
     gtk_container_add (GTK_CONTAINER (app->html_viewport),
             app->html_infopanel_view);
-    gtk_container_add (GTK_CONTAINER (app->info_area), app->info_viewport);
-    gtk_container_add (GTK_CONTAINER (app->info_area), app->html_viewport);
+    gtk_container_add (GTK_CONTAINER (info_box), app->info_viewport);
+    gtk_container_add (GTK_CONTAINER (info_box), app->html_viewport);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (info_align), 4, 2, 4, 2);
+    gtk_container_add (GTK_CONTAINER (info_align), info_box);
+    gtk_container_add (GTK_CONTAINER (app->info_area), info_align);
     g_object_ref (app->info_viewport);
     g_object_ref (app->html_viewport);
+    gtk_container_add (GTK_CONTAINER (app->video_stop), video_stop);
+
     gtk_fixed_put (GTK_FIXED (app->window_area), app->view_area, 0, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->video_stop, 730, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->title_area, 100, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->playlist_area, 0, 0);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->toolbar_area, 0, 354);
     gtk_fixed_put (GTK_FIXED (app->window_area), app->info_area, 400, 214);
-    /*g_object_set (G_OBJECT (split_view->child1),
-            "resize", TRUE, "shrink", TRUE, 0L);
-    g_object_set (G_OBJECT (split_view->child2),
-            "resize", TRUE, "shrink", TRUE, 0L);*/
     gtk_container_add (GTK_CONTAINER (main_window), app->window_area);
-    /* Create menu for view */
+
     create_menu (app);
     create_toolbar (app);
 
@@ -726,6 +745,7 @@ int main (int argc, char* argv[]) {
     gtk_widget_show_all (app->playlist_area);
     gtk_widget_show_all (app->html_viewport);
     gtk_widget_show_all (app->infopanel_view);
+    gtk_widget_show_all (info_align);
     gtk_widget_show (app->toolbar_area);
     gtk_widget_show (app->window_area);
     gtk_widget_show (GTK_WIDGET (app->window));
