@@ -183,6 +183,7 @@ void Control::init () {
     globfree (&globbuf);
 #ifdef __ARMEL__
     npp = new NpPlayer (this);
+    ((NpPlayer *)npp)->setPlayer ("/opt/kmplayer/bin/knpplayer");
 #endif
     downloader = new Downloader (this, m_app);
     String p = m_config->readEntry (GCONF_KEY_PLAYER, "osso-media-server");
@@ -1069,7 +1070,6 @@ void cbPluginAdded (GtkSocket *socket, Application *app) {
     debugLog () << "plugin embedded\n";
     app->show_playlist = false;
     ctr->videoDetected ();
-    ((NpPlayer *)ctr->npp)->pluginEmbedded ();
 #endif
 }
 
@@ -1687,6 +1687,12 @@ void Control::updateDownload (Node *node, int percentage)
 
 void Control::videoDetected ()
 {
+    Mrl *mrl = m_process ? m_process->mrl () : NULL;
+    if (mrl && mrl->audio_only) {
+        mrl->audio_only = false;
+        viewArea ()->setAudioVideoNode (mrl);
+        updateViewAreaSizes ();
+    }
     app_full_screen (m_app);
 }
 
