@@ -31,40 +31,15 @@
 #include <errno.h>
 
 #include <gtk/gtk.h>
-#define DBUS_API_SUBJECT_TO_CHANGE
-#include <dbus/dbus.h>
 
 #include "kmplayer.h"
 #include "kmplayerprocess.h"
 #ifdef __ARMEL__
-# include "npplayer.h"
 # include "kmplayer_lists.h"
 #endif
 
 using namespace KMPlayer;
 
-static void dbusSend (DBusConnection *conn,
-        const char *dest, const char *path, const char *iface,
-        const char *func, int first_arg_type, ...) {
-    va_list var_args;
-    DBusMessage *msg = dbus_message_new_method_call (
-            dest,
-            path,
-            iface,
-            func);
-    if (first_arg_type != DBUS_TYPE_INVALID) {
-        va_start (var_args, first_arg_type);
-        dbus_message_append_args_valist (msg, first_arg_type, var_args);
-        va_end (var_args);
-    }
-    dbus_message_set_no_reply (msg, TRUE);
-    dbus_connection_send (conn, msg, NULL);
-    dbus_connection_flush (conn);
-    dbus_message_unref (msg);
-}
-
-//#define dbusSend(conn, dest, path, iface, func, first_arg_type, rest...) \
-    osso_rpc_run((osso_context_t*)conn, dest, path, iface, func, NULL, first_arg_type, ## rest);
 
 Process::Process (ProcessNotify * ctrl, const char * n, bool xv)
  : m_notify (ctrl), m_viewer (0L), m_name (n),
@@ -160,6 +135,10 @@ KMPLAYER_NO_EXPORT void Process::updateAspects () {
         if (aspect < 0.01)
             aspect = m_height > 0 ? 1.0 * m_width / m_height : 0;
         m_notify->setAspect (aspect);
+        if (aspect > 0.01) {
+            no_video = false;
+            m_notify->videoDetected ();
+        }
     }
 }
 
@@ -684,7 +663,8 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (UnixProcess *) {
         } else if (outbuf[i] == '\n') {
             bool handled = false;
             outbuf[i] = 0;
-            debugLog() << "> " << tok << endl;
+            if (strncmp (tok, "dsp_thread", 10))
+                debugLog() << "> " << tok << endl;
             if (m_state == Buffering) {
                 char * p = strstr (tok, "Start");
                 if (p && strstr (p, "play")) { // find a 'Start.*play' pattern
@@ -723,14 +703,10 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (UnixProcess *) {
                         } // else ignore, a second 'pause' cmd should follow
                     } else if (!strncmp (tok + 3, "VIDEO_WIDTH", 11)) {
                         m_width = (int) strtof (tok + 15, 0L);
-                        m_notify->videoDetected ();
-                        if (m_height > 0)
-                            updateAspects ();
+                        updateAspects ();
                     } else if (!strncmp (tok + 3, "VIDEO_HEIGHT", 12)) {
                         m_height = (int) strtof (tok + 16, 0L);
-                        m_notify->videoDetected ();
-                        if (m_width > 0)
-                            updateAspects ();
+                        updateAspects ();
                     } else if (!strncmp (tok + 3, "VIDEO_ASPECT", 12)) {
                         // convert in C locale
                         m_aspect = (float) String (tok + 16).toDouble ();
@@ -795,96 +771,9 @@ KMPLAYER_NO_EXPORT bool MPlayer::sendCommand (const String & cmd) {
 
 #ifdef __ARMEL__
 
-static NSNotify ns_notify;
-
-extern "C" {
-
-static void npSetDimension (void *ndata, int w, int h) {
-    NpPlayer *player = (NpPlayer *) ndata;
-    player->setWidth (w);
-    player->setHeight (h);
-    player->updateAspects ();
-}
-
-static void npGetUrl (void *inst, uint32_t stream,
-        const char *url, const char *target,
-        unsigned plen, const char *post, void *ndata) {
-    ((NpPlayer *) ndata)->requestStream (inst, stream, url, target, plen, post);
-}
-
-static char *nsEvaluate (const char *script, void *ndata) {
-    String result = ((NpPlayer *) ndata)->evaluateScript (script);
-    if (result.isEmpty ())
-        return g_strdup ("");
-    return g_strdup ((const char *)result);
-}
-
-static void npFinish (void *inst, uint32_t stream, void *ndata) {
-    ((NpPlayer *) ndata)->destroyStream (inst, stream);
-}
-
-static gint streamCompare (gconstpointer a, gconstpointer b) {
-    return (long)a - (long)b;
-}
-
-static gboolean deleteStreams (gpointer key, gpointer value, gpointer data) {
-    (void) key;
-    delete (NpStream *)value;
-    return false; // continue
-}
-
-static gboolean copyParams (gpointer key, gpointer value, gpointer data) {
-    char ***tuple = (char ***)data;
-    tuple[0][0] = (char *)key;
-    tuple[1][0] = (char *)value;
-    tuple[0]++;
-    tuple[1]++;
-    return false; // continue
-}
-
-static gboolean openStreams (gpointer key, gpointer value, gpointer data) {
-    int active = (int)(long)data;
-    NpStream *ns = (NpStream *)value;
-    (void) key;
-    if (ns->finish_reason == NpStream::NoReason && !ns->job) {
-        ++active;
-        ns->open ();
-    }
-    return active > 4;
-}
-
-static gboolean findClosedStreams (gpointer key, gpointer value, gpointer data) {
-    NpStream *ns = (NpStream *)value;
-    (void) key;
-    if (ns->finish_reason > NpStream::NoReason) {
-        *(NpStream **)data = ns;
-        return true;
-    }
-    return false;
-}
-
-} // extern "C"
-
 KDE_NO_CDTOR_EXPORT NpPlayer::NpPlayer (ProcessNotify * ctrl)
- : Process (ctrl, "npp", false),
-   streams (NULL),
-   mime (NULL),
-   npdata (NULL),
-   argc (0),
-   argn (NULL),
-   argv (NULL),
-   processing(false) {
-    plugins = g_tree_new ((GCompareFunc)::strcmp);
-    ns_notify.setDimension = npSetDimension;
-    ns_notify.getUrl = npGetUrl;
-    ns_notify.evaluate = nsEvaluate;
-    ns_notify.finishStream = npFinish;
-}
-
-KDE_NO_CDTOR_EXPORT NpPlayer::~NpPlayer () {
-    if (mime)
-        g_free (mime);
-}
+ : MPlayer (ctrl, "npp")
+{}
 
 bool NpPlayer::isFlashMimeType (const String &mime)
 {
@@ -892,45 +781,55 @@ bool NpPlayer::isFlashMimeType (const String &mime)
         mime == "application/futuresplash";
 }
 
-KMPLAYER_NO_EXPORT bool NpPlayer::ready (unsigned int viewer) {
-    debugLog () << "NpPlayer::ready" << endl;
-    m_viewer = viewer;
-    if (m_state < Ready) {
-        // only flash for now
-        mime = g_strdup ("application/x-shockwave-flash");
-        const char *lib = "/usr/lib/browser/plugins/libflashplayer.so";
-        NPPluginLib *nplib = (NPPluginLib *) g_tree_search (plugins,
-                (GCompareFunc)::strcmp, mime);
-        if (!nplib) {
-            nplib = nppPluginInit (lib);
-            if (!nplib) {
-                warningLog() << "failed to initialize plugin lib" << endl;
-                return false;
-            }
-            g_tree_insert (plugins, (char *) mime, nplib);
-        }
-        nppInstanceWindowParent (npdata, (void *)(long)viewer);
-        setState (Ready);
-        return true;
-    }
-    return false;
+static gboolean copyParams (gpointer key, gpointer value, gpointer data) {
+    String *buf = (String *) data;
+
+    String str;
+    str += (char *)key;
+    str += Char ('=');
+    str += (char *)value;
+
+    g_free ((char *)key);
+    g_free ((char *)value);
+
+    char *quoted = g_shell_quote ((const char *) str);
+    *buf += Char (' ');
+    *buf += quoted;
+    g_free (quoted);
+
+    return false; // continue
 }
 
 KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
     if (playing ())
-        return true;
+        return pause ();
+
     setState (Buffering);
+
     Process::play (node);
+    debugLog () << "NpPlayer::play " << mrl()->mimetype << endl;
+
     if (m_url.isEmpty ()) {
         setState (Ready);
         return false;
     }
-    nppInstanceTopUrl (m_url);
-    streams = g_tree_new (streamCompare);
+
+    request_quit = false;
+    outbuf[0] = 0;
+    no_video = false;
+
+    String cmdline (path);
+    char buf[32];
+    snprintf (buf, sizeof(buf), " -wid %u ", m_viewer);
+    cmdline += String (buf);
+    cmdline += " -m application/x-shockwave-flash"
+        " -p /usr/lib/browser/plugins/libflashplayer.so ";
+    char *quoted = g_shell_quote ((const char *) m_url);
+    cmdline += quoted;
+    g_free (quoted);
 
     GTree *params = g_tree_new ((GCompareFunc)::strcmp);
     Mrl *mrl = this->mrl ();
-    debugLog () << "NpPlayer::play " << mrl->mimetype << endl;
     if (mrl->id == id_node_html_object) {
         for (Node *n = mrl->firstChild (); n; n = n->nextSibling ()) {
             /*if (n->id == KMPlayer::id_node_param) {
@@ -960,234 +859,33 @@ KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
         g_tree_insert (params, strdup ("SRC"), strdup (m_url));
         g_tree_insert (params, strdup ("flashvars"), strdup (flashvars));
     }
-    argc = g_tree_nnodes (params);
-    argn = (char **) malloc (argc * sizeof (char *));
-    argv = (char **) malloc (argc * sizeof (char *));
-    char **tuple[2] = { argn, argv };
-    g_tree_traverse (params, copyParams, G_IN_ORDER, tuple);
+    int argc = g_tree_nnodes (params);
+    if (argc) {
+        String str;
+        g_tree_traverse (params, copyParams, G_IN_ORDER, &str);
+        cmdline += " -args";
+        cmdline += str;
+    }
     g_tree_destroy (params);
 
-    npdata = nppInstanceOpen (mime, argc, argn, argv, (void *)this, &ns_notify);
-    if (!npdata) {
-        g_tree_destroy (streams);
-        streams = NULL;
-        setState (Ready);
-        warningLog() << "failed to create new instance" << endl;
-        return false;
+    String wd (getenv ("HOME"));
+    URL url (m_url);
+    is_local_file = url.isLocalFile ();
+    if (is_local_file) {
+        m_url = url.path ();
+        wd = url.path ();
+        int pos = wd.lastIndexOf (String ("/"));
+        if (pos > -1)
+            wd.truncate (pos);
     }
-    return true;
-}
 
-KMPLAYER_NO_EXPORT void NpPlayer::pluginEmbedded () {
-    if (state () == Buffering) {
-        nppInstanceStart ((const char *)m_url, mime, npdata);
-        setState (Playing);
+    if (unix_process.start (wd, cmdline)) {
+        m_mrl = node;
+        setState (Process::Buffering); //FIXME
+        return true;
     }
-}
-
-KMPLAYER_NO_EXPORT void NpPlayer::requestStream (void *inst, uint32_t sid,
-        const String & url, const String & target,
-        unsigned post_len, const char *post) {
-    URL uri (m_url, url);
-    debugLog () << "NpPlayer::request " << sid << " '" << uri << "'" << endl;
-    if (!target.isEmpty ()) {
-        debugLog () << "new page request " << target << endl;
-        if (url.startsWith ("javascript:")) {
-            String result = evaluateScript (url.mid (11));
-            debugLog() << "result is " << result << endl;
-            if (result == "undefined")
-                uri = URL ();
-            else
-                uri = URL (m_url, result); // probably wrong ..
-        }
-        /*if (!uri.url ().isEmpty ())
-            emit openUrl (uri, target);*/
-        nppStreamFinished (sid, NpStream::BecauseDone, this);
-    } else if (url.startsWith ("javascript:")) {
-        String result = evaluateScript (url.mid (11));
-        const char *data = (const char *)result;
-        nppStreamData (sid, data, strlen (data), this);
-        nppStreamFinished (sid, NpStream::BecauseDone, this);
-    } else {
-        NpStream * ns = new NpStream (this, sid, uri, post_len, post);
-        g_tree_insert (streams, (gpointer) sid, ns);
-        if (url != uri.url ())
-            nppStreamRedirected (sid, (const char *)uri.url ());
-        processStreams ();
-    }
-}
-
-KMPLAYER_NO_EXPORT void NpPlayer::destroyStream (void *inst, uint32_t sid) {
-    NpStream * ns = (NpStream *) g_tree_lookup (streams, (gpointer) sid);
-    if (ns) {
-        nppStreamFinished (sid, NpStream::BecauseStopped, this);
-        g_tree_remove (streams, (gpointer) sid);
-        delete (ns);
-    }
-}
-
-KMPLAYER_NO_EXPORT bool NpPlayer::stop () {
-    if (npdata) {
-        g_tree_foreach (streams, deleteStreams, NULL);
-        g_tree_destroy (streams);
-        streams = NULL;
-        nppInstanceClose (npdata);
-        npdata = NULL;
-        setState (Ready);
-    }
-    for (int i = 0; i < argc; i++) {
-        free (argn[i]);
-        free (argv[i]);
-    }
-    if (argn) {
-        free (argn);
-        free (argv);
-        argn = argv = NULL;
-    }
-    argc = 0;
-    return true;
-}
-
-KMPLAYER_NO_EXPORT bool NpPlayer::quit () {
-    stop ();
-    if (mime)
-        g_free (mime);
-    mime = NULL;
-    nppInstanceWindowClose (npdata); //FIXME
-    setState (NotRunning);
-    return true;
-}
-
-KMPLAYER_NO_EXPORT
-void NpPlayer::setVideoWindow (int x, int y, int w, int h) {
-    //debugLog() << "NpPlayer::setVideoWindow " << w << "x" << h << endl;
-    if (!(x < 0 || y < 0 || w <= 0 || h <= 1 /* hack !!*/ ||
-                x > 800 || y > 480 || w > 800 || h > 480))
-        nppInstanceWindowDimension (npdata, x, y, w, h);
-}
-
-KMPLAYER_NO_EXPORT void NpPlayer::processStreams () {
-    if (!processing) {
-        processing = true;
-        streams_deleted = 0;
-        int active = 0;
-        g_tree_traverse (streams, openStreams, G_IN_ORDER, &active);
-        while (streams_deleted > 0) {
-            NpStream *ns = NULL;
-            g_tree_traverse (streams, findClosedStreams, G_IN_ORDER, &ns);
-            if (ns) {
-                g_tree_remove (streams, (gpointer) ns->stream);
-                delete ns;
-            } else {
-                errorLog() << "findClosedStreams didn't find a stream" << endl;
-                break;
-            }
-            streams_deleted--;
-        }
-        processing = false;
-    }
-}
-
-KMPLAYER_NO_EXPORT void NpPlayer::streamFinished (NpStream *ns) {
-    nppStreamFinished (ns->stream, ns->finish_reason, this);
-    if (!processing) {
-        g_tree_remove (streams, (gpointer) ns->stream);
-        delete ns;
-        processStreams ();
-    } else {
-        streams_deleted++;
-    }
-}
-
-KMPLAYER_NO_EXPORT String NpPlayer::evaluateScript (const String &script) {
-    debugLog() << "evaluateScript " << script << endl;
-    if (script == "window.location+\"__flashplugin_unique__\"" ||
-            script == "top.location+\"__flashplugin_unique__\"")
-        return "http://www.example.com/__flashplugin_unique__";
-    return "undefined";
-}
-
-KDE_NO_CDTOR_EXPORT NpStream::NpStream (NpPlayer *p, uint32_t id, const URL &u,
-        unsigned post_len, const char *post)
- : player (p), stream (id), url (u), job (NULL), finish_reason (NoReason) {
-    if (post_len && post) {
-        post_data.resize (post_len);
-        memcpy (post_data.data (), post, post_len);
-    }
-}
-
-KDE_NO_CDTOR_EXPORT NpStream::~NpStream () {
-    close ();
-}
-
-KMPLAYER_NO_EXPORT void NpStream::open () {
-    debugLog () << "NpStream::open " << url.url () << endl;
-    if (url.url().startsWith ("javascript:")) {
-        String result = player->evaluateScript (url.url().mid (11));
-        const char *data = (const char *)result;
-        nppStreamData (stream, data, strlen (data), NULL /*FIXME*/);
-        finish_reason = BecauseDone;
-        player->streamFinished (this);
-    } else {
-        bytes = 0;
-        job = asyncGet (this, url.url ());
-        if (post_data.size ()) {
-            String buf;
-            int data_pos = -1;
-            bool nl = true;
-            for (int i = 0; i < post_data.size () && data_pos < 0; ++i) {
-                char c = post_data.data () [i];
-                switch (c) {
-                    case '\r':
-                        break;
-                    case '\n':
-                        if (nl)
-                            data_pos = i + 1;
-                        else
-                            job->setHeader (buf);
-                        buf.truncate (0);
-                        nl = true;
-                        break;
-                    default:
-                        nl = false;
-                        buf += Char (c);
-                }
-            }
-            job->setHeader ("Expect:");
-            if (data_pos > 0)
-                job->setHttpPostData (ByteArray (post_data.data () + data_pos,
-                            post_data.size () - data_pos));
-        }
-        job->start ();
-    }
-}
-
-KMPLAYER_NO_EXPORT void NpStream::close () {
-    if (job)
-        job->kill ();
-    if (NoReason == finish_reason)
-        nppStreamFinished (stream, BecauseStopped, player);
-    job = NULL;
-}
-
-KMPLAYER_NO_EXPORT void NpStream::jobData (IOJob *jb, ByteArray & data) {
-    //debugLog () << "NpStream::jobData " << url.url () << endl;
-    if (!bytes)
-        nppStreamInfo (stream, jb->contentType (), jb->contentLength ());
-    bytes += data.size ();
-    nppStreamData (stream, data.data (), data.size (), NULL /*FIXME*/);
-}
-
-KMPLAYER_NO_EXPORT void NpStream::jobResult (IOJob *jb) {
-    debugLog () << "NpStream::jobResult " << bytes << endl;
-    finish_reason = jb->error () || !bytes ? BecauseError : BecauseDone;
-    job = NULL;
-    player->streamFinished (this);
-}
-
-KMPLAYER_NO_EXPORT void NpStream::redirected (IOJob *, const String & uri) {
-    url = URL (url, uri);
-    nppStreamRedirected (stream, (const char *)url.url ());
+    setState (Ready);
+    return false;
 }
 
 #endif //__ARMEL__
