@@ -20,8 +20,6 @@
 http://devedge-temp.mozilla.org/library/manuals/2002/plugin/1.0/
 */
 
-#ifdef __ARMEL__
-
 #include <unistd.h>
 #include <string.h>
 #include <strings.h>
@@ -86,9 +84,9 @@ typedef struct _JsObject {
 static void print (const char * format, ...) {
     va_list vl;
     va_start (vl, format);
-    vprintf (format, vl);
+    vfprintf (stderr, format, vl);
     va_end (vl);
-    fflush (stdout);
+    fflush (stderr);
 }
 
 static void *nsAlloc (uint32 size) {
@@ -337,7 +335,6 @@ static jref nsGetJavaPeer (NPP instance) {
 
 static NPError nsGetURLNotify (NPP instance, const char* url, const char* target, void *notify) {
     (void)instance;
-    print ("NPN_GetURLNotify %s %s\n", url, target);
     addStream (url, 0L, target, 0, NULL, notify, true);
     return NPERR_NO_ERROR;
 }
@@ -915,9 +912,7 @@ void nppStreamFinished (uint32_t stream, uint32_t reason, void *pdata) {
 
 void nppStreamRedirected (uint32_t stream, const char *url) {
     StreamInfo *si = (StreamInfo *) g_tree_lookup (stream_list, stream);
-    print ("nppStreamRedirected\n");
     if (si) {
-        print ("nppStreamRedirected %s -> %s\n", si->url, url);
         g_free (si->url);
         si->url = g_strdup (url);
         si->np_stream.url = si->url;
@@ -953,23 +948,9 @@ void nppInstanceClose (void *pdata) {
 }
 
 void nppInstanceWindowClose (void *priv) {
-    Window r, p, *c;
-    unsigned int i, nr;
     (void)priv;
 
     np_window.window = NULL;
-
-    if (socket_id) {
-        Display *dpy = gdk_x11_get_default_xdisplay ();
-
-        if (XQueryTree (dpy, socket_id, &r, &p, &c, &nr)) {
-            print ("nppInstanceWindowClose chlds: %d\n", nr);
-            for (i = 0; i < nr; ++i)
-                XUnmapWindow (dpy, c[i]);
-            if (c)
-                XFree (c);
-        }
-    }
 }
 
 /*----------------%<---------------------------------------------------------*/
@@ -1000,5 +981,3 @@ void nppInstanceWindowParent (void *p, void * wid) {
     socket_id = (Window) wid;
 }
 
-
-#endif // __ARMEL__
